@@ -26,7 +26,7 @@
 #include <atk/atktext.h>
 #include <atk/atkhypertext.h>
 #include <atk/atkhyperlink.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gmacros.h>
 
 #include "gtkhtml.h"
