@@ -32,7 +32,11 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtktable.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
 #include <gdk/gdkcolor.h>
@@ -115,7 +119,7 @@ color_palette_class_init (GObjectClass *object_class)
 			      G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 }
 
-TMP_GAL_MAKE_TYPE (color_palette,
+TMP_GI_MAKE_TYPE (color_palette,
 		   "ColorPalette",
 		   ColorPalette,
 		   color_palette_class_init,
